# dist_probability_ns package

This package can be used to create, and get useful information about binomial and gaussian distibutions.

#Important Files
Generaldistribution.py: parent class for distributions

Gaussiandistribution.py: contains methods for Gaussian distributions

Binomialdistribution.py: contains methods for Binomial distributions

#Installation:

pip install dist-probability-ns